@@ -2,7 +2,7 @@ from jotdx import config
 from jotdx.consts import EX_HOSTS
 from jotdx.consts import GP_HOSTS
 from jotdx.consts import HQ_HOSTS
-from jotdx.server import Server
+from jotdx.server import server
 from jotdx.utils import get_config_path
 
-__version__ = '0.1.4'
+__version__ = '0.1.9'
