@@ -140,15 +140,19 @@ class GetInstrumentBarData(GetInstrumentBars):
 
             datetime_value = gen_datetime(year, month, day, hour, minute)
 
-            bar_data = BarData(
-                gateway_name="jotdx",
-                symbol=self.code,
-                interval=TDX_INTERVAL_MAP[self.category],
-                exchange=TDX_JONPY_MARKET_MAP[TdxMarket(self.market)],
-                open_price=open_price, high_price=high, low_price=low, close_price=close,
-                volume=trade, open_interest=position,
-                datetime=datetime_value
-            )
+            # 清理 volume 为 0 的 bar
+            if trade > 0:
+                bar_data = BarData(
+                    gateway_name="jotdx",
+                    symbol=self.code,
+                    interval=TDX_INTERVAL_MAP[self.category],
+                    exchange=TDX_JONPY_MARKET_MAP[TdxMarket(self.market)],
+                    open_price=open_price, high_price=high, low_price=low, close_price=close,
+                    volume=trade, open_interest=position,
+                    datetime=datetime_value
+                )
+            else:
+                continue
 
             klines.append(bar_data)
 
